/* SVG-Viewer Framework - define Namespace */
var SvgViewerLib = {};

/* SvgViewerRegistry *//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
SvgViewerLib.SvgViewerRegistry = function() 
{
	this.m_currentPitSvgViewerAdapter = null;
	this.m_registeredSvgViewers = [];
	this.m_currentHostAdapter = null;

	this.getCurrentPitSvgViewerAdapter = function() 
	{
		return this.m_currentPitSvgViewerAdapter;
	};
	
	this.setCurrentPitSvgViewerAdapter = function(key) 
	{
		this.m_currentPitSvgViewerAdapter = this.m_registeredSvgViewers[key];
	};
	
	this.getRegisteredSvgViewerAdapter = function() 
	{
		//Ti.API.info(this.m_registeredSvgViewers);
		return this.m_registeredSvgViewers;
	};
	
	this.addPitSvgViewerAdapter = function(adapter, key)
	{
		this.m_registeredSvgViewers[key] = adapter;
	};
};


SvgViewerLib.SvgViewerRegistryInstance = new SvgViewerLib.SvgViewerRegistry();


/* HostClientInterface *//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
SvgViewerLib.HostClientInterface = function() {
	this.name = "HostClientInterface";
};

SvgViewerLib.HostClientInterface.prototype = {
	showSvg:function(url, container, enableMode, customSVGData) {
		Ti.API.info('called SvgViewerLib.HostClientInterface.showSvg() ' + url + ' - ' + container);
	},
	insertTexts:function() {
		Ti.API.info('called SvgViewerLib.HostClientInterface.insertTexts()');
	}, 
	colorElements:function(requesturl) {
		Ti.API.info('called SvgViewerLib.HostClientInterface.colorElements()');
	}, 
	insertColoringLegend:function(requesturl, name, scale, style) {
		Ti.API.info('called SvgViewerLib.HostClientInterface.insertColoringLegend()');
	}
};


/* HostServerInterface *//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
SvgViewerLib.HostServerInterface = function() {
	this.name = "I'm ServerInterface";
};

SvgViewerLib.HostServerInterface.prototype = {
	getTooltipInfo:function(id) {
		Ti.API.info('called getTooltipInfo()');;
	},
	showObjectsInHost:function(selected_elements) {
		Ti.API.info('called showObjectsInHost(' + selected_elements + ')');
	}
};


/* HostAdapter *//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
SvgViewerLib.HostAdapter = function() {
	this.name = "I'm HostAdapter";
	
	SvgViewerLib.SvgViewerRegistryInstance.m_currentHostAdapter = this;
};


SvgViewerLib.HostAdapter.prototype = {
};

SvgViewerLib.HostAdapter.prototype = $.extend(
	{},
	SvgViewerLib.HostClientInterface.prototype,
	SvgViewerLib.HostServerInterface.prototype,
	SvgViewerLib.HostAdapter.prototype
);


/* SvgViewerClientInterface *///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
SvgViewerLib.SvgViewerClientInterface = function() {
	this.name = "SvgViewerClientInterface";
};

SvgViewerLib.SvgViewerClientInterface.prototype = {
	getTooltipInfo:function(id) {
	Ti.API.info('called getTooltipInfo(' + id + ',' + url +')');
	},
	showObjectsInHost:function(viewer) {
		Ti.API.info('called showObjectsInHost(' + selected_elements + ')');
	}
};

/* SvgViewerServerInterface *///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
SvgViewerLib.SvgViewerServerInterface = function() {
	this.name = "SvgViewerServerInterface";
};

SvgViewerLib.SvgViewerServerInterface.prototype = {
	showSvg:function(url, container, enableMode, customSVGData) {
	
		//"Init" des Viewers
		//
		var ContainerPlus = "#" + container + "";
		$(ContainerPlus).empty();
		$("#viewer").css("background","");

		var result = '';
		$.ajax({
      		url: url,
      		dataType: 'text',
      		async: false,
      		success: function (data) {
      			//nothing to do
      		},
            statusCode: {
                404: function() {
                    alert( "Fehler 404: Die URL existiert nicht" );
                }
            }
    	});

		Ti.API.info('called showSvg(' + url + ')');
	},
	insertTexts:function() {
		Ti.API.info('called insertTexts()');
	}, 
	colorElements:function(ids, colors) {
		Ti.API.info('called SvgViewerServerInterface.colorElements()');

		// if no svg available - print it to console
        if($("html").find('svg').length == 0){
            ids.forEach(function (value, index, ar) {
                Ti.API.info('ID: ' + value + ' will get color: ' + colors[index]);
            });
            return;
        }
	},
	insertColoringLegend:function(name, captions, colors, scale, textstyle) {
		Ti.API.info('called SvgViewerServerInterface.insertColoringLegend()');
	}
};

/* SvgViewerAdapter *///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
SvgViewerLib.SvgViewerAdapter = function() {
	this.name = "I'm SvgViewerAdapter";
	SvgViewerLib.SvgViewerClientInterface.call();
	SvgViewerLib.SvgViewerServerInterface.call();
	
	SvgViewerLib.SvgViewerRegistryInstance.addPitSvgViewerAdapter(this,this.name);
};

SvgViewerLib.SvgViewerAdapter.prototype = $.extend(
	{},
	SvgViewerLib.SvgViewerClientInterface.prototype,
	SvgViewerLib.SvgViewerServerInterface.prototype
);

var vieweradapter = new SvgViewerLib.SvgViewerAdapter();
var hostadapter = new SvgViewerLib.HostAdapter();
